@@ -21,6 +21,8 @@
 #ifndef FRAME_GLOM_H
 #define FRAME_GLOM_H
 
+#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+
 #include <gtkmm/frame.h>
 #include "bakery/View/View_Composite.h"
 #include <glom/libglom/document/document_glom.h>
@@ -33,8 +35,11 @@
 #include "mode_data/notebook_data.h"
 #include "mode_find/notebook_find.h"
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 #include "mode_design/dialog_fields.h"
 #include "mode_design/dialog_relationships.h"
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
 #include "dialog_connection.h"
 #include <glom/libglom/utils.h>
 
@@ -43,7 +48,10 @@
 namespace Glom
 {
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 class Dialog_Layout_Report;
+class Dialog_AddRelatedTable;
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 class Frame_Glom :
   public PlaceHolder,
@@ -57,10 +65,14 @@ public:
   void set_databases_selected(const Glib::ustring& strName);
   void on_box_tables_selected(const Glib::ustring& strName);
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_box_reports_selected(const Glib::ustring& strName);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_menu_userlevel_Developer(const Glib::RefPtr<Gtk::RadioAction>& action, const Glib::RefPtr<Gtk::RadioAction>& operator_action);
   void on_menu_userlevel_Operator(const Glib::RefPtr<Gtk::RadioAction>& action);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   void on_menu_file_export();
   void on_menu_file_print();
@@ -72,23 +84,40 @@ public:
 
   //virtual void on_menu_Navigate_Database();
   //virtual void do_menu_Navigate_Database(bool bUseList = true);
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_menu_Tables_EditTables();
+  void on_menu_Tables_AddRelatedTable();
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
   void do_menu_Navigate_Table(bool open_default = false);
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_menu_Tables_EditReports();
 
-  virtual void on_menu_developer_database_preferences();
-  virtual void on_menu_developer_fields();
-  virtual void on_menu_developer_relationships_overview();
-  virtual void on_menu_developer_relationships();
-  virtual void on_menu_developer_users();
-  virtual void on_menu_developer_layout();
-  virtual void on_menu_developer_reports();
+  void on_menu_developer_database_preferences();
+
+  void on_menu_developer_fields();
+  void do_menu_developer_fields(Gtk::Window& parent);
+
+  void on_menu_developer_relationships_overview();
+  void on_menu_developer_relationships();
+  void on_menu_developer_users();
+  void on_menu_developer_layout();
+  void on_menu_developer_reports();
+  void on_menu_developer_script_library();
 
   void on_developer_dialog_hide();
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_dialog_layout_report_hide();
   void on_dialog_reports_hide();
+#endif // !GLOM_ENABLE_CLIENT_ONLY
   void on_dialog_tables_hide();
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+
+  void on_dialog_add_related_table_request_edit_fields();
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   virtual void set_document(Document_Glom* pDocument); //View override
   virtual void load_from_document(); //View override
@@ -107,13 +136,19 @@ public:
   static void show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window& parent, Gtk::MessageType message_type = Gtk::MESSAGE_INFO);
 
   //Show the dialog to request the password, and check whether it works.
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   bool connection_request_password_and_attempt();
+#else
+  bool connection_request_password_and_attempt(std::auto_ptr<ExceptionConnection>& error);
+#endif
 
   //Show the dialog to request the password, and choose an unused database name.
   bool connection_request_password_and_choose_new_database_name();
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   ///Create the database for new documents, showing the Connection dialog
   bool create_database(const Glib::ustring& database_name, const Glib::ustring& title, bool request_password = true);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   void export_data_to_string(Glib::ustring& the_string, const FoundSet& found_set, const Document_Glom::type_mapLayoutGroupSequence& sequence);
   void export_data_to_stream(std::ostream& the_stream, const FoundSet& found_set, const Document_Glom::type_mapLayoutGroupSequence& sequence);
@@ -147,6 +182,10 @@ protected:
   void on_notebook_data_record_details_requested(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value);
   void on_userlevel_changed(AppState::userlevels userlevel);
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+  void on_dialog_add_related_table_response(int response);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
   //Member data:
   Glib::ustring m_table_name;
 
@@ -168,23 +207,32 @@ protected:
   PlaceHolder* m_pBox_Mode; //Contains e.g. design mode notebook.
 
   Box_Tables* m_pBox_Tables;
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   Box_Reports* m_pBox_Reports;
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   Notebook_Data m_Notebook_Data;
   Notebook_Find m_Notebook_Find;
 
   //Navigation:
   Dialog_Glom* m_pDialog_Tables;
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   Dialog_Glom* m_pDialog_Reports;
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   //Developer:
   Dialog_Fields* m_pDialog_Fields;
   Dialog_Relationships* m_pDialog_Relationships;
+  Dialog_AddRelatedTable* m_dialog_addrelatedtable;
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   Dialog_Connection* m_pDialogConnection;
   Gtk::Dialog* m_pDialogConnectionFailed;
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   Dialog_Layout_Report* m_pDialogLayoutReport;
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   Box_Data_List_Related m_HackToFixLinkerError; //The implementation of this class does not seem to be in the library unless I do this. murrayc.
 };
