@@ -18,6 +18,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h" // For GLOM_ENABLE_MAEMO
+
 #include "adddel.h"
 #include <algorithm> //For std::find.
 #include <glibmm/i18n.h>
@@ -29,6 +31,10 @@
 #include "bakery/App/App_Gtk.h"
 #include <iostream> //For debug output.
 
+#ifdef GLOM_ENABLE_MAEMO
+#include <hildonmm/note.h>
+#endif // GLOM_ENABLE_MAEMO
+
 #include "eggcolumnchooser/eggcolumnchooserdialog.h"
 
 namespace Glom
@@ -98,7 +104,7 @@ void AddDel::init()
   set_prevent_user_signals();
   set_ignore_treeview_signals();
 
-  set_spacing(6);
+  set_spacing(Utils::DEFAULT_SPACING_SMALL);
 
   m_bAllowUserActions = true;
 
@@ -143,13 +149,20 @@ AddDel::~AddDel()
 
 void AddDel::warn_about_duplicate()
 {
-  Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Duplicate")), true, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_OK);
-  //TODO: dialog.set_transient_for(get_parent_window());
+  Glib::ustring message;
 
   if(m_prevent_duplicates_warning.empty())
-    dialog.set_secondary_text(_("This item already exists. Please try again."));
+    message = _("This item already exists. Please try again.");
   else
-    dialog.set_secondary_text(m_prevent_duplicates_warning); //Something more specific and helpful.
+    message = m_prevent_duplicates_warning; //Something more specific and helpful.
+
+#ifdef GLOM_ENABLE_MAEMO
+  Hildon::Note dialog(Hildon::NOTE_TYPE_INFORMATION, message);
+#else
+  Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Duplicate")), true, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_OK);
+  dialog.set_secondary_text(message);
+#endif
+  //TODO: dialog.set_transient_for(get_parent_window());
 
   dialog.run();
 }
@@ -660,7 +673,7 @@ void AddDel::construct_specified_columns()
           if(pCellRenderer)
           {
             //Make it editable:
-            pCellRenderer->property_editable() = true;
+	    g_object_set(pCellRenderer->gobj(), "editable", TRUE, (gpointer)NULL);
 
             //Connect to its signal:
             pCellRenderer->signal_edited().connect(
@@ -672,7 +685,7 @@ void AddDel::construct_specified_columns()
            Gtk::CellRendererToggle* pCellRenderer = dynamic_cast<Gtk::CellRendererToggle*>(m_TreeView.get_column_cell_renderer(view_column_index));
            if(pCellRenderer)
            {
-             pCellRenderer->property_activatable() = true;
+             g_object_set(pCellRenderer->gobj(), "activatable", TRUE, (gpointer)NULL);
 
              //Connect to its signal:
              pCellRenderer->signal_toggled().connect(
@@ -1291,7 +1304,9 @@ void AddDel::on_treeview_button_press_event(GdkEventButton* event)
     Gtk::TreeView::Column* pColumn = 0;
     int cell_x = 0;
     int cell_y = 0;  
-    bool row_exists = m_TreeView.get_path_at_pos((int)event->x, (int)event->y, path, pColumn, cell_x, cell_y);
+
+    // Make sure to use the non-deprecated const version:
+    bool row_exists = static_cast<const Gtk::TreeView&>(m_TreeView).get_path_at_pos((int)event->x, (int)event->y, path, pColumn, cell_x, cell_y);
 
     if(row_exists)
     {
