@@ -33,6 +33,7 @@
 //#include "../cellrendererlist.h"
 #include <iostream> //For debug output.
 #include <gtk/gtktreeview.h>
+#include <gtk/gtkstock.h>
 
 namespace Glom
 {
@@ -82,7 +83,7 @@ DbAddDel::DbAddDel()
   set_prevent_user_signals();
   set_ignore_treeview_signals(true);
 
-  set_spacing(6);
+  set_spacing(Utils::DEFAULT_SPACING_SMALL);
 
   //Start with a useful default TreeModel:
   //set_columns_count(1);
@@ -120,15 +121,20 @@ DbAddDel::DbAddDel()
   remove_all_columns(); //set up the default columns.
 
   show_all_children();
+
+  // Adjust sizing when style changed
+  signal_style_changed().connect(sigc::mem_fun(*this, &DbAddDel::on_self_style_changed));
 }
 
 DbAddDel::~DbAddDel()
 {
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   App_Glom* pApp = get_application();
   if(pApp)
   {
     pApp->remove_developer_action(m_refContextLayout);
   } 
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 }
 
 void
@@ -170,11 +176,13 @@ DbAddDel::on_MenuPopup_activate_Edit()
   }
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 void DbAddDel::on_MenuPopup_activate_layout()
 {
   finish_editing();
   signal_user_requested_layout().emit();
 }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 void DbAddDel::on_MenuPopup_activate_Add()
 {
@@ -231,6 +239,9 @@ void DbAddDel::setup_menu()
     sigc::mem_fun(*this, &DbAddDel::on_MenuPopup_activate_Add) );
   m_refContextAdd->set_sensitive(m_allow_add);
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+  // Don't add ContextLayout in client only mode because it would never
+  // be sensitive anyway
   m_refContextLayout =  Gtk::Action::create("ContextLayout", _("Layout"));
   m_refActionGroup->add(m_refContextLayout,
     sigc::mem_fun(*this, &DbAddDel::on_MenuPopup_activate_layout) );
@@ -242,6 +253,7 @@ void DbAddDel::setup_menu()
     pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
     pApp->update_userlevel_ui(); //Update our action's sensitivity. 
   }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   m_refUIManager = Gtk::UIManager::create();
 
@@ -249,24 +261,37 @@ void DbAddDel::setup_menu()
 
   //TODO: add_accel_group(m_refUIManager->get_accel_group());
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
+#endif
     Glib::ustring ui_info = 
         "<ui>"
         "  <popup name='ContextMenu'>"
         "    <menuitem action='ContextEdit'/>"
         "    <menuitem action='ContextAdd'/>"
         "    <menuitem action='ContextDelete'/>"
-        "    <menuitem action='ContextLayout'/>"        
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+        "    <menuitem action='ContextLayout'/>"
+#endif
         "  </popup>"
         "</ui>";
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
     m_refUIManager->add_ui_from_string(ui_info);
   }
   catch(const Glib::Error& ex)
   {
     std::cerr << "building menus failed: " <<  ex.what();
   }
+#else
+  std::auto_ptr<Glib::Error> error;
+  m_refUIManager->add_ui_from_string(ui_info, error);
+  if(error.get() != NULL)
+  {
+    std::cerr << "building menus failed: " << error->what();
+  }
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
   //Get the menu:
   m_pMenuPopup = dynamic_cast<Gtk::Menu*>( m_refUIManager->get_widget("/ContextMenu") ); 
@@ -285,12 +310,15 @@ void DbAddDel::setup_menu()
     m_refContextDelete->set_sensitive(false);
   }
  
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   if(pApp)
     m_refContextLayout->set_sensitive(pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 }
 
 bool DbAddDel::on_button_press_event_Popup(GdkEventButton *event)
 {
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   //Enable/Disable items.
   //We did this earlier, but get_application is more likely to work now:
   App_Glom* pApp = get_application();
@@ -322,6 +350,7 @@ bool DbAddDel::on_button_press_event_Popup(GdkEventButton *event)
   }
 
   return  false; //Not handled. TODO: Call base class?
+#endif
 }
 
 Gtk::TreeModel::iterator DbAddDel::get_item_placeholder()
@@ -596,9 +625,9 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
 
        Glib::RefPtr<Gdk::Pixbuf> pixbuf = Conversions::get_pixbuf_for_gda_value(item_image->get_image());
        if(pixbuf)
-         pixbuf_renderer->property_pixbuf() = pixbuf;
+         pixbuf_renderer->set_property("pixbuf", pixbuf);
        else
-         pixbuf_renderer->property_stock_id() = Gtk::Stock::MISSING_IMAGE.id; //TODO: Specify stock size?
+         pixbuf_renderer->set_property("stock-id", Gtk::Stock::MISSING_IMAGE);
 
        pCellRenderer = pixbuf_renderer;
      }
@@ -608,7 +637,7 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
        if(item_text)
        {
          Gtk::CellRendererText* pCellText = Gtk::manage( new Gtk::CellRendererText() );
-         pCellText->property_text() = item_text->get_text();
+	 pCellText->set_property("text", item_text->get_text());
 
          pCellRenderer = pCellText;
        }
@@ -618,7 +647,7 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
          if(item_button)
          {
            GlomCellRenderer_ButtonText* pCellButton = Gtk::manage( new GlomCellRenderer_ButtonText() );
-           pCellButton->property_text() = item_button->get_title_or_name();
+	   pCellButton->set_property("text", item_button->get_title_or_name());
            //pCellButton->set_fixed_width(50); //Otherwise it doesn't show up. TODO: Discover the width of the contents.
 
            pCellButton->signal_clicked().connect(
@@ -638,7 +667,7 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
     //Use an ellipze to indicate excessive text, 
     //so that similar values do not look equal, 
     //and to avoid multi-line comments. TODO: Is there a better way to restrict the height? This doesn't actually truncate multilines anyway.
-    pCellRendererText->property_ellipsize() = Pango::ELLIPSIZE_END;
+    g_object_set(pCellRendererText->gobj(), "ellipsize", PANGO_ELLIPSIZE_END, (gpointer)NULL);
 
     //Restrict the height, to prevent multiline text cells,
     //and to allow TreeView performance optimisation:
@@ -648,11 +677,11 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
     if(item_field) //Only fields can be edited:
     {
       //Make it editable:
-      pCellRendererText->property_editable() = true;
+      pCellRendererText->set_property("editable", true);
 
       //Align numbers to the right: //TODO: Avoid this for ID keys.
       if(item_field->get_glom_type() == Field::TYPE_NUMERIC )
-        pCellRenderer->property_xalign() = 1.0f; //Align right.
+        pCellRendererText->set_property("xalign", 1.0);
 
       //Connect to its signal:
       pCellRendererText->signal_edited().connect(
@@ -724,7 +753,7 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const shar
     Gtk::CellRendererToggle* pCellRendererToggle = dynamic_cast<Gtk::CellRendererToggle*>(pCellRenderer);
     if(pCellRendererToggle)
     {
-      pCellRendererToggle->property_activatable() = true;
+      pCellRendererToggle->set_property("activatable", true);
 
       if(item_field) //Only fields can be edited:
       {
@@ -848,9 +877,20 @@ void DbAddDel::construct_specified_columns()
     m_treeviewcolumn_button = Gtk::manage(new Gtk::TreeViewColumn());
     m_treeviewcolumn_button->pack_start(*pCellButton);
 
+
+    int x_offset, y_offset, width, height;
+    pCellButton->get_size(m_TreeView, x_offset, y_offset, width, height);
+
     m_treeviewcolumn_button->set_sizing(Gtk::TREE_VIEW_COLUMN_FIXED); //Need by fixed-height mode.
-    m_treeviewcolumn_button->set_fixed_width(25); //Otherwise it doesn't show up. TODO: Discover the width of the contents.
-    m_treeviewcolumn_button->property_visible() = true; //get_allow_view_details();
+
+    // TODO: I am not sure whether this is always correct. Perhaps, we also
+    // have to take into account the xpad property of the cell renderer and
+    // the spacing property of the treeviewcolumn.
+    int horizontal_separator;
+    m_TreeView.get_style_property("horizontal-separator", horizontal_separator);
+    m_treeviewcolumn_button->set_fixed_width(width + horizontal_separator*2);
+
+    m_treeviewcolumn_button->set_property("visible", true);
 
     m_TreeView.append_column(*m_treeviewcolumn_button);
 
@@ -1519,10 +1559,12 @@ DbAddDel::type_signal_user_changed DbAddDel::signal_user_changed()
   return m_signal_user_changed;
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 DbAddDel::type_signal_user_requested_layout DbAddDel::signal_user_requested_layout()
 {
   return m_signal_user_requested_layout;
 }
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 DbAddDel::type_signal_user_requested_delete DbAddDel::signal_user_requested_delete()
 {
@@ -1566,7 +1608,9 @@ void DbAddDel::on_treeview_button_press_event(GdkEventButton* event)
     Gtk::TreeView::Column* pColumn = 0;
     int cell_x = 0;
     int cell_y = 0;  
-    bool row_exists = m_TreeView.get_path_at_pos((int)event->x, (int)event->y, path, pColumn, cell_x, cell_y);
+
+    // Make sure to use the non-deprecated const version:
+    bool row_exists = static_cast<const Gtk::TreeView&>(m_TreeView).get_path_at_pos((int)event->x, (int)event->y, path, pColumn, cell_x, cell_y);
 
     //Get the row:
     if(row_exists)
@@ -1655,9 +1699,7 @@ guint DbAddDel::treeview_append_column(const Glib::ustring& title, Gtk::CellRend
   pViewColumn->signal_clicked().connect(
     sigc::bind( sigc::mem_fun(*this, &DbAddDel::on_treeview_column_clicked), model_column_index) );
 
-
-  pViewColumn->property_width().signal_changed().connect( 
-    sigc::bind( sigc::mem_fun(*this, &DbAddDel::on_treeview_column_resized), model_column_index, pViewColumn) );
+  pViewColumn->connect_property_changed("width", sigc::bind(sigc::mem_fun(*this, &DbAddDel::on_treeview_column_resized), model_column_index, pViewColumn) );
 
   return cols_count;
 }
@@ -1912,7 +1954,7 @@ void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gt
             if(pixbuf)
               pixbuf = ImageGlom::scale_keeping_ratio(pixbuf,  get_fixed_cell_height(), pixbuf->get_width());
 
-            pDerived->property_pixbuf() = pixbuf;
+            g_object_set(pDerived->gobj(), "pixbuf", pixbuf->gobj(), (gpointer)NULL);
           }
           else
             g_warning("Field::sql(): glom_type is TYPE_IMAGE but gda type is not VALUE_TYPE_BINARY");
@@ -1927,7 +1969,7 @@ void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gt
           {
             const Glib::ustring text = Conversions::get_text_for_gda_value(field->get_glom_type(), value, field->get_formatting_used().m_numeric_format);
             //g_assert(text != "NULL");
-            pDerived->property_text() = text;
+            g_object_set(pDerived->gobj(), "text", text.c_str(), (gpointer)NULL);
           }
 
           break;
@@ -1956,7 +1998,7 @@ void DbAddDel::set_allow_view_details(bool val)
 
   //Hide it if it was visible:
   if(m_treeviewcolumn_button)
-    m_treeviewcolumn_button->property_visible() = get_allow_view_details();
+    g_object_set(m_treeviewcolumn_button->gobj(), "visible", get_allow_view_details() ? TRUE : FALSE, (gpointer)NULL);
 }
 
 bool DbAddDel::get_allow_view_details() const
@@ -1975,6 +2017,14 @@ void DbAddDel::on_cell_button_clicked(const Gtk::TreeModel::Path& path)
   on_MenuPopup_activate_Edit();
 }
 
+void DbAddDel::on_self_style_changed(const Glib::RefPtr<Gtk::Style>& style)
+{
+  // Reset fixed cell height because the font might have changed due to the new style
+  m_fixed_cell_height = 0;
+  // Reconstruct columns because sizes might have changed
+  construct_specified_columns();
+}
+
 void DbAddDel::set_open_button_title(const Glib::ustring& title)
 {
   m_open_button_title = title;
